@@ -6,13 +6,13 @@ use warnings;
 use Log::Any '$log';
 
 use File::Remove qw(remove);
-use Perinci::Access::Schemeless 0.32;
+use Perinci::Access::Schemeless;
 use Perinci::Tx::Manager;
 use Scalar::Util qw(blessed);
 use Test::More 0.98;
 use UUID::Random;
 
-our $VERSION = '0.45'; # VERSION
+our $VERSION = '0.46'; # VERSION
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -512,13 +512,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Perinci::Tx::Manager - Transaction tests
 
 =head1 VERSION
 
-version 0.45
+version 0.46
 
 =head1 FUNCTIONS
 
@@ -568,13 +570,29 @@ function.
 
 =back
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Tx-Manager>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Tx-Manager>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Tx-Manager>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
